import * as queryOptions from '../queryOptionTypes';
import { Holiday, HolidayScheme } from '../requestTypes';
import { HolidaySchemeResponse, HolidayResponse, ResultSetResponse, UserResponse } from '../responseTypes';
import Collection from './abstractCollection';
export default class HolidaySchemes extends Collection {
    /**
     * Retrieve all holiday schemes
     */
    get(): Promise<ResultSetResponse<HolidaySchemeResponse>>;
    /**
     * Create a Holiday scheme
     */
    post(holidayScheme: HolidayScheme): Promise<HolidaySchemeResponse>;
    /**
     * Retrieve an existing holiday scheme
     */
    getHolidayScheme(id: string): Promise<HolidaySchemeResponse>;
    /**
     * Update a holiday scheme
     */
    putHolidayScheme(id: string, holidayScheme: HolidayScheme): Promise<HolidaySchemeResponse>;
    /**
     * Delete a holiday scheme
     */
    deleteHolidayScheme(id: string): Promise<void>;
    /**
     * Set the default holiday scheme
     */
    putHolidaySchemeDefault(id: string): Promise<HolidaySchemeResponse>;
    /**
     * Retrieve holidays for an existing holiday scheme
     */
    getHolidaySchemeHolidays(id: string, options: queryOptions.Year): Promise<ResultSetResponse<HolidayResponse>>;
    /**
     * Create a Holiday
     */
    postHolidaySchemeHoliday(id: string, holiday: Holiday): Promise<HolidayResponse>;
    /**
     * Retrieve an existing holiday
     */
    getHolidaySchemeHoliday(id: string, holidayId: string): Promise<HolidayResponse>;
    /**
     * Update a holiday
     */
    putHolidaySchemeHoliday(id: string, holidayId: string, holiday: Holiday): Promise<HolidayResponse>;
    /**
     * Delete a holiday
     */
    deleteHolidaySchemeHoliday(id: string, holidayId: string): Promise<void>;
    /**
     * Retrieve all floating holidays for an existing holiday scheme.
     */
    getHolidaySchemeFloatingHolidays(id: string): Promise<ResultSetResponse<HolidayResponse>>;
    /**
     * Get members in a holiday scheme
     *
     * Note: Tempo.io documentation seems to be broken.
     */
    getHolidaySchemeMembers(id: string): Promise<ResultSetResponse<UserResponse>>;
    /**
     * Assign a holiday scheme to members
     */
    postHolidaySchemeMembers(id: string, accountIds: string[]): Promise<void>;
    /**
     * Get user scheme
     */
    getForUser(accountId: string): Promise<ResultSetResponse<HolidaySchemeResponse>>;
}
