"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstractCollection_1 = require("./abstractCollection");
class PermissionRoles extends abstractCollection_1.default {
    /**
     * Retrieve permission roles
     */
    get(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/permission-roles', {
                query: options,
            });
        });
    }
    /**
     * Create a new editable permission role
     */
    post(permissionRole) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/permission-roles', {
                body: permissionRole,
                method: 'POST',
            });
        });
    }
    /**
     * Retrieve global permission roles
     */
    getGlobal() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/permission-roles/global');
        });
    }
    /**
     * Retrieve a permission role
     */
    getPermissionRole(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/permission-roles/${id}`);
        });
    }
    /**
     * Update a permission role. Only members of editable roles can be updated.
     */
    putPermissionRole(id, permissionRole) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/permission-roles/${id}`, {
                body: permissionRole,
                method: 'PUT',
            });
        });
    }
    /**
     * Delete an editable permission role
     */
    deletePermissionRole(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.createAndSendRequest(`/permission-roles/${id}`, {
                method: 'DELETE',
            });
        });
    }
}
exports.default = PermissionRoles;
//# sourceMappingURL=permissionRoles.js.map