"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstractCollection_1 = require("./abstractCollection");
class WorkloadSchemes extends abstractCollection_1.default {
    /**
     * Retrieve all workload schemes
     */
    get() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/workload-schemes');
        });
    }
    /**
     * Create a workload scheme
     */
    post(workloadScheme) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest('/workload-schemes', {
                body: workloadScheme,
                method: 'POST',
            });
        });
    }
    /**
     * Retrieve an existing workload scheme for the given id
     */
    getWorkloadScheme(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}`);
        });
    }
    /**
     * Update a workload scheme for the given id
     */
    putWorkloadScheme(id, workloadScheme) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}`, {
                body: workloadScheme,
                method: 'PUT',
            });
        });
    }
    /**
     * Delete a workload scheme for the given id
     */
    deleteWorkloadScheme(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}`, {
                method: 'DELETE',
            });
        });
    }
    /**
     * Set the default workload scheme
     */
    putWorkloadSchemeDefault(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}/default`, {
                method: 'PUT',
            });
        });
    }
    /**
     * Get members in a workload scheme
     */
    getWorkloadSchemeMembers(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}/members`);
        });
    }
    /**
     * Set user workload scheme membership
     */
    postWorkloadSchemeMembers(id, accountIds) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/${id}/members`, {
                body: { accountIds },
                method: 'POST',
            });
        });
    }
    /**
     * Get user scheme
     */
    getForUser(accountId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createAndSendRequest(`/workload-schemes/users/${accountId}`);
        });
    }
}
exports.default = WorkloadSchemes;
//# sourceMappingURL=workloadSchemes.js.map