"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const querystring_1 = require("querystring");
class Builder {
    constructor(options) {
        this.protocol = options.protocol || 'https';
        this.intermediatePath = options.intermediatePath;
        this.port = options.port;
        this.host = options.host;
        this.apiVersion = options.apiVersion;
        this.baseOptions = {};
        if (options.bearerToken) {
            this.baseOptions.headers = {
                Authorization: `Bearer ${options.bearerToken}`,
            };
        }
        if (options.timeout) {
            this.baseOptions.timeout = options.timeout;
        }
    }
    buildRequestConfig(url, { method, body } = {}) {
        return Object.assign({ body, method: method || 'GET', url }, this.baseOptions);
    }
    buildUrl({ pathname, query, intermediatePath }) {
        const intermediateToUse = this.intermediatePath || intermediatePath;
        const tempPath = intermediateToUse || `/core/${this.apiVersion}`;
        const url = new URL('https://example.com');
        url.host = this.host;
        url.pathname = `${tempPath}${pathname}`;
        if (this.port !== undefined) {
            url.port = this.port;
        }
        url.protocol = this.protocol;
        url.search = (0, querystring_1.stringify)(query);
        return decodeURIComponent(url.href);
    }
}
exports.default = Builder;
//# sourceMappingURL=builder.js.map